from genericpath import exists
from pathlib import Path, PurePath
from typing import Optional
from pathlib import Path, PurePath
import typer


__app_name__ = "saki"
__version__ = "1.0.0"

app = typer.Typer()

SIZE = 64*1024




def get_file(path: str) -> PurePath:
    file = Path(path)

    return file

@app.command()
def read(path: str) -> None:
    if path == None:
        typer.echo("No path specified")
        return
    else:
        if exists(path):
            file = get_file(path=path)

            with open(file, 'r') as f:
                chunk = f.read(SIZE)

                while len(chunk) > 0:
                    typer.echo(chunk)
                    chunk = f.read(SIZE)
    

def _version_callback(value: bool) -> None:
    if value:
        typer.echo(f"{__app_name__} v{__version__}")
        raise typer.Exit()

@app.callback()
def main(
    version: Optional[bool] = typer.Option(
        None,
        "--version",
        "-v",
        help="Show the application's version and exit.",
        callback=_version_callback,
        is_eager=True,
    )
) -> None:
    return



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['saki']

package_data = \
{'': ['*']}

install_requires = \
['typer[all]>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['saki = saki.main:app']}

setup_kwargs = {
    'name': 'saki',
    'version': '1.0.0',
    'description': 'A simple alternative to the cat command line tool',
    'long_description': '# Saki\n\n![](https://www.beardsleyzoo.org/uploads/1/2/4/2/124214186/245_orig.jpg)\n\n## Desciption\n\nSaki is an alternative to the cat command\n',
    'author': 'Luke Pitstick',
    'author_email': 'lukepitstick06@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
